==> kf5-kpackage-debuginfo-5.39.0-1.tar.xz: usr/src/debug/kf5-kpackage-5.39.0-1/src/kpackagetool/CMakeFiles/kpackagetool5.dir/qrc_kpackagetool.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/kf5-kpackage/kf5-kpackage-5.39.0-1.i686/src/kpackage-5.39.0/src/kpackage/data/servicetypes/kpackage-generic.desktop
  0x0,0x0,0x0,0xdd,
  0x5b,
  0x44,0x65,0x73,0x6b,0x74,0x6f,0x70,0x20,0x45,0x6e,0x74,0x72,0x79,0x5d,0xa,0x54,
  0x79,0x70,0x65,0x3d,0x53,0x65,0x72,0x76,0x69,0x63,0x65,0x54,0x79,0x70,0x65,0xa,
  0x58,0x2d,0x4b,0x44,0x45,0x2d,0x53,0x65,0x72,0x76,0x69,0x63,0x65,0x54,0x79,0x70,
  0x65,0x3d,0x4b,0x50,0x61,0x63,0x6b,0x61,0x67,0x65,0x2f,0x47,0x65,0x6e,0x65,0x72,
  0x69,0x63,0xa,0xa,0x5b,0x50,0x72,0x6f,0x70,0x65,0x72,0x74,0x79,0x44,0x65,0x66,
  0x3a,0x3a,0x58,0x2d,0x50,0x6c,0x61,0x73,0x6d,0x61,0x2d,0x52,0x6f,0x6f,0x74,0x50,
  0x61,0x74,0x68,0x5d,0xa,0x54,0x79,0x70,0x65,0x3d,0x51,0x53,0x74,0x72,0x69,0x6e,
  0x67,0xa,0xa,0x5b,0x50,0x72,0x6f,0x70,0x65,0x72,0x74,0x79,0x44,0x65,0x66,0x3a,
  0x3a,0x58,0x2d,0x50,0x6c,0x61,0x73,0x6d,0x61,0x2d,0x4d,0x61,0x69,0x6e,0x53,0x63,
  0x72,0x69,0x70,0x74,0x5d,0xa,0x54,0x79,0x70,0x65,0x3d,0x51,0x53,0x74,0x72,0x69,
  0x6e,0x67,0xa,0xa,0x5b,0x50,0x72,0x6f,0x70,0x65,0x72,0x74,0x79,0x44,0x65,0x66,
  0x3a,0x3a,0x58,0x2d,0x4b,0x50,0x61,0x63,0x6b,0x61,0x67,0x65,0x2d,0x44,0x65,0x70,
  0x65,0x6e,0x64,0x65,0x6e,0x63,0x69,0x65,0x73,0x5d,0xa,0x54,0x79,0x70,0x65,0x3d,
  0x51,0x53,0x74,0x72,0x69,0x6e,0x67,0x4c,0x69,0x73,0x74,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // kservicetypes5
  0x0,0xe,
  0xf,0x53,0xef,0xe5,
  0x0,0x6b,
  0x0,0x73,0x0,0x65,0x0,0x72,0x0,0x76,0x0,0x69,0x0,0x63,0x0,0x65,0x0,0x74,0x0,0x79,0x0,0x70,0x0,0x65,0x0,0x73,0x0,0x35,
    // kpackage-generic.desktop
  0x0,0x18,
  0x5,0x2c,0xf9,0x20,
  0x0,0x6b,
  0x0,0x70,0x0,0x61,0x0,0x63,0x0,0x6b,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x2d,0x0,0x67,0x0,0x65,0x0,0x6e,0x0,0x65,0x0,0x72,0x0,0x69,0x0,0x63,0x0,0x2e,
  0x0,0x64,0x0,0x65,0x0,0x73,0x0,0x6b,0x0,0x74,0x0,0x6f,0x0,0x70,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/kservicetypes5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/kservicetypes5/kpackage-generic.desktop
  0x0,0x0,0x0,0x22,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5e,0xf8,0x48,0x7a,0x8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_kpackagetool)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_kpackagetool)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kpackagetool)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kpackagetool)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_kpackagetool)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kpackagetool)(); }
   } dummy;
}

==> kf5-kpackage-debuginfo-5.43.0-1.tar.xz: usr/src/debug/kf5-kpackage-5.43.0-1/src/kpackagetool/CMakeFiles/kpackagetool5.dir/qrc_kpackagetool.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.4
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/kf5-kpackage/kf5-kpackage-5.43.0-1.x86_64/src/kpackage-5.43.0/src/kpackage/data/kservicetypes5/kpackage-generic.desktop
  0x0,0x0,0x0,0xdd,
  0x5b,
  0x44,0x65,0x73,0x6b,0x74,0x6f,0x70,0x20,0x45,0x6e,0x74,0x72,0x79,0x5d,0xa,0x54,
  0x79,0x70,0x65,0x3d,0x53,0x65,0x72,0x76,0x69,0x63,0x65,0x54,0x79,0x70,0x65,0xa,
  0x58,0x2d,0x4b,0x44,0x45,0x2d,0x53,0x65,0x72,0x76,0x69,0x63,0x65,0x54,0x79,0x70,
  0x65,0x3d,0x4b,0x50,0x61,0x63,0x6b,0x61,0x67,0x65,0x2f,0x47,0x65,0x6e,0x65,0x72,
  0x69,0x63,0xa,0xa,0x5b,0x50,0x72,0x6f,0x70,0x65,0x72,0x74,0x79,0x44,0x65,0x66,
  0x3a,0x3a,0x58,0x2d,0x50,0x6c,0x61,0x73,0x6d,0x61,0x2d,0x52,0x6f,0x6f,0x74,0x50,
  0x61,0x74,0x68,0x5d,0xa,0x54,0x79,0x70,0x65,0x3d,0x51,0x53,0x74,0x72,0x69,0x6e,
  0x67,0xa,0xa,0x5b,0x50,0x72,0x6f,0x70,0x65,0x72,0x74,0x79,0x44,0x65,0x66,0x3a,
  0x3a,0x58,0x2d,0x50,0x6c,0x61,0x73,0x6d,0x61,0x2d,0x4d,0x61,0x69,0x6e,0x53,0x63,
  0x72,0x69,0x70,0x74,0x5d,0xa,0x54,0x79,0x70,0x65,0x3d,0x51,0x53,0x74,0x72,0x69,
  0x6e,0x67,0xa,0xa,0x5b,0x50,0x72,0x6f,0x70,0x65,0x72,0x74,0x79,0x44,0x65,0x66,
  0x3a,0x3a,0x58,0x2d,0x4b,0x50,0x61,0x63,0x6b,0x61,0x67,0x65,0x2d,0x44,0x65,0x70,
  0x65,0x6e,0x64,0x65,0x6e,0x63,0x69,0x65,0x73,0x5d,0xa,0x54,0x79,0x70,0x65,0x3d,
  0x51,0x53,0x74,0x72,0x69,0x6e,0x67,0x4c,0x69,0x73,0x74,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // kservicetypes5
  0x0,0xe,
  0xf,0x53,0xef,0xe5,
  0x0,0x6b,
  0x0,0x73,0x0,0x65,0x0,0x72,0x0,0x76,0x0,0x69,0x0,0x63,0x0,0x65,0x0,0x74,0x0,0x79,0x0,0x70,0x0,0x65,0x0,0x73,0x0,0x35,
    // kpackage-generic.desktop
  0x0,0x18,
  0x5,0x2c,0xf9,0x20,
  0x0,0x6b,
  0x0,0x70,0x0,0x61,0x0,0x63,0x0,0x6b,0x0,0x61,0x0,0x67,0x0,0x65,0x0,0x2d,0x0,0x67,0x0,0x65,0x0,0x6e,0x0,0x65,0x0,0x72,0x0,0x69,0x0,0x63,0x0,0x2e,
  0x0,0x64,0x0,0x65,0x0,0x73,0x0,0x6b,0x0,0x74,0x0,0x6f,0x0,0x70,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/kservicetypes5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/kservicetypes5/kpackage-generic.desktop
  0x0,0x0,0x0,0x22,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x61,0x65,0xd8,0x2e,0x90,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_kpackagetool)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_kpackagetool)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kpackagetool)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kpackagetool)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_kpackagetool)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kpackagetool)(); }
   } dummy;
}
